@@ -12,15 +12,19 @@ OC.L10N.register(
     "Day" : "Día",
     "Week" : "Semana",
     "Month" : "Mes",
+    "List" : "Lista",
     "Download" : "Descargar",
     "Delete" : "Borrar",
     "Share link" : "Compartir liga",
+    "Copy public link" : "Copiar enlace público",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
     "New calendar" : "Nuevo calendario",
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "or" : "o",
+    "Actions" : "Acciones",
     "Show week numbers" : "Mostrar número de semana",
     "Settings & import" : "Configuraciones & importar",
     "Notification" : "Notificación",
@@ -39,12 +43,13 @@ OC.L10N.register(
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
     "Reminders" : "Recordatorios",
-    "Activity" : "Actividad",
     "Close" : "Cerrar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
     "Weekly" : "Semanalmente",
+    "next year" : "próximo año",
+    "today" : "hoy",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
     "When shared hide this event" : "Al compartir, ocultar este evento ",
@@ -53,7 +58,7 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Tentative" : "Tentativo",
-    "Cancelled" : "Cancelado",
+    "Canceled" : "Cancelada",
     "Categories" : "Categorías",
     "Presentation" : "Presentación",
     "Office" : "Office",
