@@ -23,6 +23,7 @@ OC.L10N.register(
     "Day" : "Dagur",
     "Week" : "Vika",
     "Month" : "Mánuður",
+    "List" : "Listi",
     "Untitled calendar" : "Ónefnt dagatal",
     "Edit name" : "Breyta heiti",
     "Saving name …" : "Vista heiti …",
@@ -47,9 +48,11 @@ OC.L10N.register(
     "Send link to calendar via email" : "Senda tengil á dgatal með tölvupósti",
     "Enter one address" : "Settu inn eitt netfang",
     "Sending email …" : "Sendi tölvupóst ...",
+    "Copy subscription link" : "Afrita áskriftartengil",
     "Copying link …" : "Afrita tengil …",
     "Copied link" : "Afritaði tengil",
     "Could not copy link" : "Gat ekki afritað tengil",
+    "Copy embedding code" : "Afrita ívafningarkóða",
     "Copying code …" : "Afrita kóða …",
     "Copied code" : "Afritaði kóða",
     "Could not copy code" : "Gat ekki afritað kóða",
@@ -57,6 +60,8 @@ OC.L10N.register(
     "Deleting share link …" : "Eyði tengli á sameign …",
     "An error occurred, unable to publish calendar." : "Villa kom upp, gat ekki gefið út dagatalið.",
     "An error occurred, unable to send email." : "Villa kom upp, gat ekki sent tölvupóst.",
+    "Embed code copied to clipboard." : "Ívafningarkóði afritaður á klippispjald.",
+    "Embed code could not be copied to clipboard." : "Ekki var hægt að afrita ívafningarkóða á klippispjald.",
     "Unpublishing calendar failed" : "Mistókst að hætta birtingu dagatals",
     "Share with users or groups" : "Deila með notendum eða hópum",
     "No users or groups" : "Engir notendur eða hópar",
@@ -68,6 +73,7 @@ OC.L10N.register(
     "New calendar" : "Nýtt dagatal",
     "Creating calendar …" : "Útbý dagatal …",
     "New calendar with task list" : "Nýtt dagatal með verkefnalista",
+    "New subscription from link (read-only)" : "Ný áskrift úr tengli (skrifvarið)",
     "Creating subscription …" : "Útbý áskrift …",
     "An error occurred, unable to create the calendar." : "Villa kom upp, gat ekki búið til dagatalið.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Skráðu inn gilda slóð (starting with http://, https://, webcal://, or webcals://)",
@@ -77,13 +83,19 @@ OC.L10N.register(
     "Calendar to import into" : "Dagatal til að flytja inn í",
     "Cancel" : "Hætta við",
     "_Import calendar_::_Import calendars_" : ["Flytja inn dagatal","Flytja inn dagatöl"],
+    "{filename} is an unsupported file-type" : "{filename} er óstudd skráartegund",
+    "{filename} could not be parsed" : "Ekki var hægt að þátta {filename}",
+    "No valid files found, aborting import" : "Engar gildar skrár fundust, hætti innflutningi",
     "_Successfully imported %n event_::_Successfully imported %n events._" : ["Innflutningur tókst á %n atburði","Innflutningur tókst á %n atburðum"],
     "Automatic" : "Sjálfvirkt",
     "Automatic ({detected})" : "Sjálfvirkt ({detected})",
     "New setting was not saved successfully." : "Ekki tókst að vista nýju stillinguna.",
     "Shortcut overview" : "Yfirlit flýtilykla",
     "or" : "eða",
+    "Navigation" : "Yfirsýn",
     "Previous period" : "Fyrra tímabil",
+    "Next period" : "Næsta tímabil",
+    "Views" : "Skoðun",
     "Day view" : "Dagsyfirlit",
     "Week view" : "Vikuyfirlit",
     "Month view" : "Mánaðaryfirlit",
@@ -104,6 +116,8 @@ OC.L10N.register(
     "Notification" : "Tilkynning",
     "Email" : "Tölvupóstur",
     "Audio notification" : "Hljóðáminning",
+    "Other notification" : "Önnur áminning",
+    "Relative to event" : "Miðað við atburð",
     "Edit time" : "Breyta tíma",
     "Save time" : "Vista tíma",
     "Remove reminder" : "Fjarlægja áminningu",
@@ -117,7 +131,6 @@ OC.L10N.register(
     "_week_::_weeks_" : ["vika","vikur"],
     "No reminders yet" : "Engar áminningar ennþá",
     "Availability of attendees, resources and rooms" : "Framboð á þátttakendum, tilföngum og herbergjum",
-    "Attendees, Resources and Rooms" : "Þáttakendur, tilföng og herbergi",
     "Busy (tentative)" : "Upptekinn (með fyrirvara)",
     "Busy" : "Upptekinn",
     "Out of office" : "Ekki á staðnum",
@@ -185,15 +198,16 @@ OC.L10N.register(
     "Please enter a valid date and time" : "Settu inn gilda dags- og tímasetningu",
     "Type to search timezone" : "Skrifaðu hér til að leita að tímabelti",
     "Personal" : "Persónulegt",
+    "[Today]" : "[Í dag]",
+    "[Tomorrow]" : "[Á morgun]",
+    "[Yesterday]" : "[Í gær]",
     "Delete this occurrence" : "Eyða þessu tilviki",
     "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
     "Details" : "Nánar",
     "Attendees" : "Þáttakendur",
     "Reminders" : "Áminningar",
-    "Activity" : "Virkni",
-    "Projects" : "Verkefni",
-    "Show more details" : "Sýna frekari upplýsingar",
     "Close" : "Loka",
+    "Show more details" : "Sýna frekari upplýsingar",
     "Subscribe to {name}" : "Panta áskrift að {name}",
     "Download {name}" : "Sækja {name}",
     "Anniversary" : "Afmæli",
@@ -220,10 +234,12 @@ OC.L10N.register(
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "í {monthNames} þann {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "þangað til {untilDate}",
     "_%n time_::_%n times_" : ["%n sinni","%n sinnum"],
-    "Please ask your administrator to enable the Tasks App." : "Biddu kerfisstjórann þinn um að virkja verkefnasorritið (Tasks).",
-    "_+%n more_::_+%n more_" : ["+%n til viðbótar","+%n til viðbótar"],
     "Untitled event" : "Ónefndur atburður",
     "Untitled task" : "Ónefnt verkefni",
+    "Please ask your administrator to enable the Tasks App." : "Biddu kerfisstjórann þinn um að virkja verkefnasorritið (Tasks).",
+    "next year" : "á næsta ári",
+    "today" : "í dag",
+    "_+%n more_::_+%n more_" : ["+%n til viðbótar","+%n til viðbótar"],
     "When shared show" : "Þegar er deilt, birta ",
     "When shared show full event" : "Þegar er deilt, birta allan atburð",
     "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
@@ -236,7 +252,7 @@ OC.L10N.register(
     "Status" : "Staða",
     "Confirmed" : "Staðfest",
     "Tentative" : "Með fyrirvara",
-    "Cancelled" : "Hætt við",
+    "Canceled" : "Hætt við",
     "Confirmation about the overall status of the event." : "Staðfesting á almennri stöðu atburðarins.",
     "Show as" : "Birta sem",
     "Take this event into account when calculating free-busy information." : "Taka þennan atburð með í reikninga á laus/upptekinn upplýsingum.",
@@ -262,8 +278,11 @@ OC.L10N.register(
     "Baseball" : "Hornabolti",
     "Meet" : "Hittast",
     "Planning" : "Skipulagning",
+    "Pointing" : "Bending",
+    "Retrospective" : "Endurskoðun",
     "Review" : "Yfirfara",
     "Office" : "Skrifstofa",
+    "Contributor week" : "Vika með þátttakendum",
     "Party" : "Partý",
     "Celebration" : "Hátíðahöld",
     "Mail" : "Póstur",
@@ -292,6 +311,7 @@ OC.L10N.register(
     "Dentist" : "Tannlæknir",
     "Interview" : "Viðtal",
     "Training" : "Þjálfun",
+    "Practice" : "Æfingar",
     "Sports" : "Íþróttir",
     "Exercise" : "Æfing",
     "Work out" : "Líkamsrækt",
