@@ -95,8 +95,10 @@ OC.L10N.register(
     "New setting was not saved successfully." : "Thiết lập mới không được lưu thành công",
     "Shortcut overview" : "Bản xem trước của lối tắt",
     "or" : "hoặc",
+    "Navigation" : "Điều hướng",
     "Previous period" : "Kỳ trước",
     "Next period" : "Kỳ tiếp theo",
+    "Views" : "Lượt xem",
     "Day view" : "Xem theo ngày",
     "Week view" : "Xem theo tuần",
     "Month view" : "Xem theo tháng",
@@ -161,6 +163,7 @@ OC.L10N.register(
     "No match found" : "Không có khớp lệnh nào được tìm thấy",
     "No attendees yet" : "Chưa có giờ tham gia",
     "(organizer)" : "(organizer)",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Để gửi lời mời và tiếp nhận các phản hồi, [linkopen] thêm địa chỉ email riêng của bạn trong phần cài đặt cá nhân[linkclose].",
     "Remove color" : "Gỡ màu",
     "Event title" : "Tiêu đề sự kiện",
     "All day" : "Cả ngày",
@@ -218,6 +221,12 @@ OC.L10N.register(
     "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Tự động phát hiện múi giờ xác định múi giờ của bạn trên hệ thống UTC. \nĐây gần như là một trong những kết quả của các phương thức bảo mật của trình duyệt của bạn.\nVui lòng đặt múi giờ của bạn một cách thủ công trong các thiết lập của Lịch. ",
     "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Múi giờ được cấu hình của bạn ({timezoneId}) không được tìm thấy. Đang trở về lại hệ thống UTC.\nVui lòng thay đổi múi giờ của bạn trong Thiết lập và báo cáo vấn đề này. ",
     "No more events today" : "Không có thêm sự kiện nào hôm nay",
+    "No upcoming events" : "Không có sự kiện sắp diễn ra ",
+    "Create a new event" : "Tạo một sự kiện mới",
+    "[Today]" : "[Hôm nay]",
+    "[Tomorrow]" : "[Ngày mai]",
+    "[Yesterday]" : "[Hôm qua]",
+    "[Last] dddd" : "[Trước] dddd",
     "Event does not exist" : "Sự kiện không tồn tại",
     "Delete this occurrence" : "Xóa định kỳ này",
     "Delete this and all future" : "Xóa địnhy kỳ này và tất cả tương lai của nó",
